==> redhat-fuse-7.10.0-sources.zip: fuse-karaf-7.10.0.fuse-7_10_0-00011-redhat-00001/modules/fabric8-karaf/fabric8-karaf-checks/src/main/java/io/fabric8/karaf/checks/internal/WarState.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * <p/>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p/>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.fabric8.karaf.checks.internal;

import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

import io.fabric8.karaf.checks.Check;
import org.ops4j.pax.web.service.spi.WebEvent;
import org.ops4j.pax.web.service.spi.WebListener;
import org.osgi.framework.Bundle;

public class WarState extends AbstractBundleChecker
                            implements WebListener {

    private final Map<Long, WebEvent> states = new ConcurrentHashMap<>();

    public WarState() {
        bundleContext.registerService(WebListener.class, this, null);
    }

    @Override
    public void webEvent(WebEvent event) {
        states.put(event.getBundle().getBundleId(), event);
    }

    @Override
    public Check checkBundle(Bundle bundle) {
        WebEvent event = states.get(bundle.getBundleId());
        if (event != null && event.getType() != WebEvent.DEPLOYED && isActive(bundle)) {
            return new Check("war-state", "War bundle " + bundle.getBundleId() + " is in state " + getState(event));
        }
        return null;
    }

    private String getState(WebEvent webEvent) {
        switch (webEvent.getType()) {
            case WebEvent.DEPLOYED:
                return "DEPLOYED";
            case WebEvent.DEPLOYING:
                return "DEPLOYING";
            case WebEvent.FAILED:
                return "FAILED";
            case WebEvent.UNDEPLOYED:
                return "UNDEPLOYED";
            case WebEvent.UNDEPLOYING:
                return "UNDEPLOYING";
            case WebEvent.WAITING:
                return "WAITING";
            default:
                return "UNKNOWN";
        }
    }

}

==> redhat-fuse-7.13.0-sources.zip: fuse-karaf-7.13.0.fuse-7_13_0-00012-redhat-00001/modules/fabric8-karaf/fabric8-karaf-checks/src/main/java/io/fabric8/karaf/checks/internal/WarState.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * <p/>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p/>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.fabric8.karaf.checks.internal;

import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

import io.fabric8.karaf.checks.Check;
import org.ops4j.pax.web.service.spi.model.events.WebApplicationEvent;
import org.ops4j.pax.web.service.spi.model.events.WebApplicationEventListener;
import org.osgi.framework.Bundle;

public class WarState extends AbstractBundleChecker
                            implements WebApplicationEventListener {

    private final Map<Long, WebApplicationEvent> states = new ConcurrentHashMap<>();

    public WarState() {
        bundleContext.registerService(WebApplicationEventListener.class, this, null);
    }

    @Override
    public void webEvent(WebApplicationEvent event) {
        states.put(event.getBundle().getBundleId(), event);
    }

    @Override
    public Check checkBundle(Bundle bundle) {
        WebApplicationEvent event = states.get(bundle.getBundleId());
        if (event != null && event.getType() != WebApplicationEvent.State.DEPLOYED && isActive(bundle)) {
            return new Check("war-state", "War bundle " + bundle.getBundleId() + " is in state " + getState(event));
        }
        return null;
    }

    private String getState(WebApplicationEvent webEvent) {
        switch (webEvent.getType()) {
            case DEPLOYED:
                return "DEPLOYED";
            case DEPLOYING:
                return "DEPLOYING";
            case FAILED:
                return "FAILED";
            case UNDEPLOYED:
                return "UNDEPLOYED";
            case UNDEPLOYING:
                return "UNDEPLOYING";
            case WAITING:
                return "WAITING";
            default:
                return "UNKNOWN";
        }
    }

}
